@@ -10,6 +10,12 @@ class AlertViewlet(ViewletBase):
     def update(self):
         properties_tool = getToolByName(self.context, 'portal_properties')
         properties = getattr(properties_tool, 'alertviewlet_properties', None)
-        self.message = properties.getProperty('message', None)
-        self.showViewlet = properties.getProperty('showViewlet', False)
+        
+        if properties is not None:
+            self.message = properties.getProperty('message', None)
+            self.showViewlet = properties.getProperty('showViewlet', False)
+        else:
+            self.message = ''
+            self.showViewlet = False
+        
     
